//
//  ViewController.m
//  人脸检测
//
//  Created by 卢鹏肖 on 16/3/14.
//  Copyright © 2016年 卢鹏肖. All rights reserved.
//

#import "ViewController.h"
#import <CoreImage/CoreImage.h>

@interface ViewController ()

@property(nonatomic,strong)CIContext *context;

@property (weak, nonatomic) IBOutlet UIImageView *imageView;

/**
 *  检测器
 */
@property(nonatomic,strong)CIDetector *detector;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.imageView.contentMode = UIViewContentModeScaleAspectFit;
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
    //获取图片
    UIImage *image = self.imageView.image;
    //转成ciimage
    CIImage *ciImage = [CIImage imageWithCGImage:image.CGImage];
    //拿到所有的脸
     NSArray <CIFeature *> *featureArray = [self.detector featuresInImage:ciImage];
    //遍历
    for (CIFeature *feature in featureArray)
    {
        //将image沿y轴对称
        CGAffineTransform transform = CGAffineTransformScale(CGAffineTransformIdentity, 1, -1);
        //将image往上移动
        CGFloat imageH = ciImage.extent.size.height;
        transform = CGAffineTransformTranslate(transform, 0, -imageH);
        //在image上画出方框
        CGRect feaRect = feature.bounds;
        //调整后的坐标
        CGRect newFeaRect = CGRectApplyAffineTransform(feaRect, transform);
        //调整imageView的frame
        CGFloat imageViewW = self.imageView.bounds.size.width;
        CGFloat imageViewH = self.imageView.bounds.size.height;
        CGFloat imageW = ciImage.extent.size.width;
        //显示
        CGFloat scale = MIN(imageViewH / imageH, imageViewW / imageW);
        //缩放
        CGAffineTransform scaleTransform = CGAffineTransformMakeScale(scale, scale);
        
        //修正
        newFeaRect = CGRectApplyAffineTransform(newFeaRect, scaleTransform);
        newFeaRect.origin.x +=  (imageViewW - imageW * scale) / 2;
        newFeaRect.origin.y += (imageViewH - imageH * scale) / 2;
        
        //绘画
        UIView *breageView = [[UIView alloc] initWithFrame:newFeaRect];
        breageView.layer.borderColor = [UIColor redColor].CGColor;
        breageView.layer.borderWidth = 2;
        [self.imageView addSubview:breageView];
    }
}

#pragma mark -- 懒加载
- (CIContext *)context
{
    if (_context == nil)
    {
        _context = [CIContext contextWithOptions:nil];
    }
    return _context;
}

- (CIDetector *)detector
{
    if (_detector == nil)
    {
        NSDictionary *dict = @{
                               CIDetectorAccuracy : CIDetectorAccuracyHigh
                               };
        _detector = [CIDetector detectorOfType:CIDetectorTypeFace context:self.context options:dict];
    }
    return _detector;
}



@end
